@@ -3,3 +3,5 @@ from .lhy_io_utils import *
 from .lhy_log_utils import *
 from .lhy_net_utils import *
 from .lhy_tool_utils import *
+from .lhy_module_utils import *
+from .lhy_tf_utils import *
